#pragma GCC optimize("O3")

#include <iostream>
#include <iomanip>
#include <cstdint>
#include <cassert>
#include <cstring>

#define MAX_N 36

double pl, pr;
int64_t n, l, r;

enum Error {
	N_ERROR,
	L_ERROR,
	R_ERROR,
	ERRORS,
};

double sol[MAX_N][MAX_N][ERRORS];
double tmp[MAX_N][MAX_N][ERRORS];

void add_sol(int32_t l, int32_t r, int32_t e, double v) {
	if (l < 0) l = 0;
	if (r < 0) r = 0;

	if (r > n) {
		r = n;
		assert(e == N_ERROR);
		e = R_ERROR;
	}

	if (l > n) {
		l = n;
		assert(e == N_ERROR);
		e = L_ERROR;
	}

	sol[l][r][e] += v;
}

void do_step() {
	memcpy(tmp, sol, sizeof tmp);
	memset(sol, 0, sizeof sol);

	for (int32_t l = 0; l <= n; l += 1)
	for (int32_t r = 0; r <= n; r += 1) {
		add_sol(l, r,   N_ERROR, tmp[l][r][L_ERROR] * pl);
		add_sol(l, r-1, L_ERROR, tmp[l][r][L_ERROR] * pr);

		add_sol(l-1, r, R_ERROR, tmp[l][r][R_ERROR] * pl);
		add_sol(l,   r, N_ERROR, tmp[l][r][R_ERROR] * pr);

		if (l == n && r == n) continue;

		if (l == r) {
			add_sol(l+1, r,   N_ERROR, tmp[l][r][N_ERROR] * pl);
			add_sol(l,   r+1, N_ERROR, tmp[l][r][N_ERROR] * pr);
		}
		if (l  < r) {
			add_sol(l+1, r, N_ERROR, tmp[l][r][N_ERROR] * pl);
			add_sol(l,   r, R_ERROR, tmp[l][r][N_ERROR] * pr);
		}
		if (l  > r) {
			add_sol(l, r,   L_ERROR, tmp[l][r][N_ERROR] * pl);
			add_sol(l, r+1, N_ERROR, tmp[l][r][N_ERROR] * pr);
		}
	}
}

int main() {
	std::ios_base::sync_with_stdio(0);
	std::cin .tie(0);
	std::cout.tie(0);

	std::cin>> pl >> n >> l >> r;

	pr = 1 - pl;

	sol[l][r][N_ERROR] = 1;

	double sum = 0;
	double curr_step = 0;

	double avg_step = curr_step * sum;

	while (true) {
		avg_step += sol[n][n][N_ERROR] * curr_step;

		sum += sol[n][n][N_ERROR];
		if (1 - sum <= 1e-09) break;

		// if ((int32_t)curr_step % 10 == 0) std::cout << sol[n][n][N_ERROR] << ' ' << sum << std::endl;

		do_step();
		curr_step += 1;
	}

	std::cout << std::setprecision(12) << avg_step << std::endl;
}
