#include <iostream>
#include <vector>
#include <algorithm>
#include <map>
#include <queue>

using namespace std;
#define int long long
const int INF = 1e13;
const int IINF = 1e18;

int n, cur_cost = 0, len = 0;
vector <pair <int, int>> a;
map <pair <int, int>, int> ex;
vector <int> in, out, taken;

inline int get_edge(int i, int j) {
    return abs(a[i].second - a[j].first);
}

inline int get_left(int i) {
    return 2 + i;
}

inline int get_right(int i) {
    return n + 2 + i;
}

bool push_flow() {
    vector <int> d(len, IINF), used(len), pr(len, -1);
    d[0] = 0;
    queue <int> q;
    used[0] = 1;
    q.push(0);

    auto relax = [&](int i, int x, int p) {
        if (d[i] > x) {
            d[i] = x;
            pr[i] = p;
            if (!used[i]) {
                used[i] = 1;
                q.push(i);
            }
        }
    };

    while (!q.empty()) {
        int pos = q.front();
        q.pop();
        used[pos] = 0;
        if (pos == 1) continue;
        if (pos == 0) {
            for (int i = 0; i < n; ++i) {
                if (taken[i]) continue;
                relax(get_left(i), 0, 0);
            }
            continue;
        }
        if (pos <= n + 1) {
            int i = pos - 2;
            if (in[pos] == -1) {
                relax(get_right(i), d[pos] - INF, pos);
            } else {
                if (in[pos] != 0) relax(in[pos], d[pos] - get_edge(in[pos] - (n + 2), i), pos);
            }
        } else {
            int i = pos - (n + 2);
            if (in[pos] == -1) {
                for (int j = i + 1; j < n; ++j) {
                    relax(get_left(j), d[pos] + get_edge(i, j), pos);
                }
                relax(1, d[pos], pos);
            } else {
                for (int j = i + 1; j < n; ++j) {
                    if (get_left(j) == out[pos]) continue;
                    relax(get_left(j), d[pos] + get_edge(i, j), pos);
                }
                relax(1, d[pos], pos);
                relax(in[pos], d[pos] + INF, pos);
            }
        }
    }
    if (d[1] == IINF) return false;
    cur_cost += d[1];
    int cur = 1;
    in.assign(len, -1);
    out.assign(len, -1);
    while (cur > 0) {
        int p = pr[cur];
        if (p == 0) taken[cur - 2] = 1;
        ex[make_pair(cur, p)] ^= 1;
        ex[make_pair(p, cur)] ^= 1;
        cur = p;
    }
    for (auto i : ex) {
        if (i.second == 1) {
            int u = i.first.first;
            int v = i.first.second;
            if (u > v) continue;
            if (u == 0) {
                in[v] = 0;
            } else if (u == 1) {
                out[v] = 1;
            } else {
                if (u + n == v) {
                    out[u] = v;
                    in[v] = u;
                } else {
                    out[v] = u;
                    in[u] = v;
                }
            }
        }
    }
    return true;
}

inline void solve() {
    int k;
    cin >> n >> k;
    len = 2 * n + 2;
    a.resize(n);
    in.resize(len, -1);
    out.resize(len, -1);
    taken.resize(n);
    for (int i = 0; i < n; ++i) cin >> a[i].first >> a[i].second;
    int ans = INF;
    while (k) {
        if (!push_flow()) break;
        ans = min(ans, cur_cost);
        k--;
    }
    cout << ans + n * INF;
}

int gen(vector <int>& st, int k) {
    if ((int)st.size() == n) {
        int now = 0;
        for (int i = 0; i < n; ++i) {
            for (int j = i + 1; j < n; ++j) {
                if (st[i] == st[j]) {
                    now += get_edge(i, j);
                    break;
                }
            }
        }
        if (now == 2) {
            for (int i : st) cout << i << " ";
            exit(0);
        }
        return now;
    }
    int now = INF;
    for (int i = 0; i < k; ++i) {
        st.push_back(i);
        now = min(now, gen(st, k));
        st.pop_back();
    }
    return now;
}

inline void stupid() {
    int k;
    cin >> n >> k;
    a.resize(n);
    for (int i = 0; i < n; ++i) cin >> a[i].first >> a[i].second;
    vector <int> st;
    cout << gen(st, k);
}

signed main() {
    if (1) {
        ios_base::sync_with_stdio(false);
        cin.tie(nullptr);
        cout.tie(nullptr);
    }
    if (1) {
        solve();
    } else {
        stupid();
    }
}

/*
3 2
5 20
8 100
2 80

7 4
8 2
9 8
9 3
4 3
6 4
3 4
10 9

 */