#include <bits/stdc++.h>

constexpr int inf = 1.01e9;
constexpr int64_t INF = 1e18;

struct Flow {
    struct Edge {
        int to, id;
        int cap, cost, flow;
    };

    std::vector<std::vector<Edge>> gr;
    std::vector<std::pair<int64_t, int>> dist;
    int64_t flow, cost;
    int n, S, T;

    Flow(int n, int S, int T) : n(n), S(S), T(T) {
        gr.resize(n);
        dist.resize(n);
        flow = 0;
        cost = 0;
    }

    void add_dir_edge(int u, int v, int cap, int cost) {
        int a = gr[u].size();
        int b = gr[v].size();
        gr[u].push_back({v, b, cap, cost, 0});
        gr[v].push_back({u, a, cap, -cost, cap});
    }

    std::vector<Edge*> FB() {
        dist.assign(n, {INF, -1});
        dist[S] = {0, -2};
        std::deque<int> deque;
        std::vector<bool> in_queue(n, false);
        in_queue[S] = true;
        deque.push_back(S);
        while (!deque.empty()) {
            int v = deque.front();
            deque.pop_front();
            in_queue[v] = false;
            for (auto& e : gr[v]) {
                if (e.cap != e.flow && dist[e.to].first > dist[v].first + e.cost) {
                    dist[e.to] = {dist[v].first + e.cost, e.id};
                    if (!in_queue[e.to]) {
                        deque.push_back(e.to);
                        in_queue[e.to] = true;
                    }
                }
            }
        }
        if (dist[T].first > INF / 2) {
            return {};
        }
        int v = T;
        std::vector<Edge*> res;
        while (v != S) {
            int id = dist[v].second;
            res.push_back(&gr[gr[v][id].to][gr[v][id].id]);
            v = gr[v][id].to;
            assert(res.size() < 1e7);
        }
        return res;
    }

    void push(Edge& e, int dlt) {
        cost += e.cost * dlt;
        e.flow += dlt;
        gr[e.to][e.id].flow -= dlt;
    }

    int64_t min_cost() {
        while (true) {
            auto vec = FB();
            if (vec.empty()) {
                break;
            }
            flow += 1;
            for (auto& e : vec) {
                assert(e->flow < e->cap);
                push(*e, 1);
            }
        }
        return cost;
    }
};

int32_t main() {
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(nullptr);

    int n, k;
    std::cin >> n >> k;
    std::vector<std::pair<int, int>> input(n);
    for (auto& [l, r] : input) {
        std::cin >> l >> r;
    }
    Flow fl(2 * n + 3, 0, 2 * n + 2);
    fl.add_dir_edge(0, 1, k, 0);
    for (int i = 0; i < n; i++) {
        fl.add_dir_edge(1, 2 + i, 1, 0);
        fl.add_dir_edge(2 + i, 2 + n + i, 1, -inf);
        fl.add_dir_edge(2 + n + i, 2 * n + 2, 1, 0);
    }
    for (int i = 0; i < n; i++) {
        for (int j = i + 1; j < n; j++) {
            fl.add_dir_edge(2 + n + i, 2 + j, 1, abs(input[i].second - input[j].first));
        }
    }

    int64_t ans = fl.min_cost();
    ans += inf * 1LL * n;
    std::cout << ans << "\n";

    return 0;
}
