#pragma GCC target("avx512f,avx512vl,avx512dq,avx512bw,bmi,bmi2,lzcnt")
// #pragma GCC optimize("O3")
#include <any>
#include <iostream>
#include <sstream>
#define private public
#include <bits/stdc++.h>
#include <immintrin.h>

constexpr int inf = 1.01e9;
constexpr int64_t INF = 1e18;

struct Flow {
    struct Edge {
        short cap, flow;
        int cost;
    };

    std::vector<std::map<int, Edge>> gr;
    std::vector<int64_t> dist;
    std::vector<int> link;
    std::vector<int64_t> phi;
    int64_t flow, cost;
    int sz, S, T;
    int n;

    std::vector<int64_t> beg, end;

    Flow(int sz, int S, int T, int n) : n(n), sz(sz), S(S), T(T), beg(sz), end(sz) {
        gr.resize(sz);
        dist.resize(sz);
        link.resize(sz);
        phi.assign(sz, 0);
        flow = 0;
        cost = 0;
    }

    void add_dir_edge(int u, int v, int cap, int cost) {
        gr[u][v] = Edge{(short)cap, short(0), cost};
        gr[v][u] = Edge{(short)cap, (short)cap, -cost};
    }

    std::vector<int> get_path() {
        if (dist[T] > INF / 2) {
            return {};
        }
        int v = T;
        std::vector<int> res;
        while (v != S) {
            res.push_back(v);
            v = link[v];
            assert(res.size() < 1e7);
        }
        res.push_back(S);
        std::reverse(res.begin(), res.end());
        return res;
    }

    void initial_dfs() {
        dist.assign(sz, INF);
        std::vector<bool> used(sz);
        dist[S] = {0};
        link[S] = -2;
        used[S] = true;
        auto dfs = [&](auto dfs, int v) {
            if (used[v]) {
                return;
            }
            used[v] = true;
            for (const auto& [to, e] : gr[v]) {
                if (e.flow != 0) {
                    dfs(dfs, to);
                    int64_t nw = dist[to] - e.cost;
                    if (dist[v] > nw) {
                        dist[v] = nw;
                        link[v] = to;
                    }
                }
            }
            if (2 <= v && v < 2 + n) {
                for (int t = n + 2; t < v + n; t++) {
                    dfs(dfs, t);
                    int64_t nw = dist[t] + abs(beg[v - 2] - end[t - 2 - n]);
                    if (dist[v] > nw) {
                        dist[v] = nw;
                        link[v] = t;
                    }
                }
            }
        };
        for (int i = 0; i < sz; i++) {
            dfs(dfs, i);
        }
    }

    void copy_dist_to_phi() {
        for (int i = 0; i < sz; i++) {
            phi[i] = dist[i] + phi[i];
        }
    }

    // void FB() {
    //     dist.assign(sz, {INF, -1});
    //     dist[S] = {0, -2};
    //     std::deque<int> deque;
    //     std::vector<bool> in_queue(sz, false);
    //     in_queue[S] = true;
    //     deque.push_back(S);
    //     while (!deque.empty()) {
    //         int v = deque.front();
    //         deque.pop_front();
    //         in_queue[v] = false;
    //         for (auto& e : gr[v]) {
    //             if (e.cap != e.flow) {
    //                 int64_t dlt = e.cost + phi[v] - phi[e.to];
    //                 assert(dlt >= 0);
    //                 if (dist[e.to].first > dist[v].first + dlt) {
    //                     dist[e.to] = {dist[v].first + dlt, e.id};
    //                     if (!in_queue[e.to]) {
    //                         deque.push_back(e.to);
    //                         in_queue[e.to] = true;
    //                     }
    //                 }
    //             }
    //         }
    //     }
    // }

    auto& get_cum(int v) {
        static std::vector<std::pair<int, Edge>> res;
        res.clear();
        if (2 <= v && v < 2 + 2 * n) {
            if (v >= 2 + n) {
                for (int t = v - n + 1; t < 2 + n; t++) {
                    res.push_back({t, Edge{(short)1, short(0), (int)abs(end[v - 2 - n] - beg[t - 2])}});
                }
                for (auto& [to, e] : gr[v]) {
                    int it = std::lower_bound(res.begin(), res.end(), std::pair{to, e}, [&](const auto& a, const auto& b) { return a.first < b.first; }) - res.begin();

                    if (it < res.size() && res[it].first == to) {
                        res[it].first = -1;
                    }
                }
                res.erase(std::remove_if(res.begin(), res.end(), [&](const auto& a) { return a.first == -1; }), res.end());
            }
        }
        return res;
    }

    void DJ() {
        dist.assign(sz, INF);
        link.assign(sz, -1);
        dist[S] = 0;
        // std::vector<int> used(sz, false);
        std::bitset<int(1e4)> used;
        for (int i = 0; i < sz; i++) {
            std::pair<int64_t, int> min(INF, -1);
            for (int j = 0; j < sz; j++) {
                if (!used[j]) {
                    min = std::min(min, std::pair<int64_t, int>{dist[j], j});
                }
            }
            if (min.second == -1) {
                break;
            }
            auto [d, v] = min;
            used[v] = true;
            for (const auto& [to, e] : gr[v]) {
                if (e.flow != e.cap && !used[to]) {
                    int64_t dlt = phi[v] - phi[to] + e.cost;
                    assert(dlt >= 0);
                    int64_t nw = dist[v] + dlt;
                    if (dist[to] > nw) {
                        dist[to] = nw;
                        link[to] = v;
                    }
                }
            }

            if (2 + n <= v && v < 2 + 2 * n) {
                static std::vector<std::pair<int, int>> help;
                help.clear();
                static std::vector<int> fuck;
                fuck.clear();
                const int L = v - n;
                const int R = 2 + n;
                fuck.push_back(L);
                fuck.push_back(R);
                for (auto& [to, e] : gr[v]) {
                    fuck.push_back(std::max(std::min(to, R), L));
                }
                std::sort(fuck.begin(), fuck.end());
                fuck.erase(std::unique(fuck.begin(), fuck.end()), fuck.end());
                assert(fuck.size() <= 40);

                for (int i = 0; i + 1 < fuck.size(); i++) {
                    help.push_back({fuck[i] + 1, fuck[i + 1]});
                }

                int end_val = end[v - 2 - n];
                int64_t base = dist[v] + phi[v];

                for (auto& [l, r] : help) {
                    // #pragma GCC ivdep
                    auto upd = [&](int i) {
                        if (used[i]) {
                            return;
                        }
                        int64_t dlt = abs(end_val - beg[i - 2]) - phi[i];
                        int64_t nw = base + dlt;
                        if (dist[i] > nw) {
                            dist[i] = nw;
                            link[i] = v;
                            // dist[i] = std::min(dist[i], {base + dlt, v});
                        }
                    };
                    if (r - l <= 16) {
                        for (int i = l; i < r; i++) {
                            upd(i);
                        }
                    } else {
                        while (l % 8) {
                            upd(l++);
                        }
                        while (r % 8) {
                            upd(--r);
                        }

                        __m512i v_end = _mm512_set1_epi64(end_val);
                        __m512i v_base = _mm512_set1_epi64(base);
                        __m256i v_v = _mm256_set1_epi32(v);

                        for (int i = l; i < r; i += 8) {
                            // assert(i % 8 == 0);
                            uint8_t mask = ((uint8_t*)(used._M_w))[i / 8];
                            mask = ~mask;

                            __m512i v_beg = _mm512_loadu_si512(&beg[i - 2]);
                            __m512i v_phi = _mm512_loadu_si512(&phi[i]);
                            __m512i v_dist = _mm512_loadu_si512(&dist[i]);
                            __m256i v_link = _mm256_loadu_si256((__m256i*)&link[i]);

                            // int64_t dlt = llabs(end_val - beg[i - 2]) - phi[i];

                            __m512i v_dlt = _mm512_sub_epi64(
                                _mm512_abs_epi64(_mm512_sub_epi64(v_end, v_beg)),
                                v_phi);

                            __m512i v_nw = _mm512_add_epi64(v_base, v_dlt);
                            mask = mask & _mm512_cmpgt_epi64_mask(v_dist, v_nw);

                            // mask = ~mask;

                            v_nw = _mm512_mask_blend_epi64(mask, v_dist, v_nw);
                            v_link = _mm256_mask_blend_epi32(mask, v_link, v_v);

                            _mm512_storeu_epi64(&dist[i], v_nw);
                            _mm256_storeu_epi32(&link[i], v_link);

                            // if (dist[i] > nw) {
                            //     dist[i] = nw;
                            //     link[i] = v;
                            //     // dist[i] = std::min(dist[i], {base + dlt, v});
                            // }
                        }
                    }
                }
            }
        }
    }

    void insert_edge(int fr, int to) {
        if (to < fr) {
            std::swap(to, fr);
        }
        assert(2 <= fr && fr < 2 + n);
        assert(2 + n <= to && to < 2 + 2 * n);
        assert(fr - 2 > to - 2 - n);
        add_dir_edge(to, fr, 1, abs(end[to - 2 - n] - beg[fr - 2]));
    }

    void push(int fr, int to, int dlt) {
        if (gr[fr].find(to) == gr[fr].end()) {
            insert_edge(fr, to);
        }
        auto& e = gr[fr][to];
        cost += e.cost * dlt;
        e.flow += dlt;
        gr[to][fr].flow -= dlt;
    }

    int64_t min_cost() {
        initial_dfs();
        copy_dist_to_phi();
        // FB();
        while (true) {
            auto vec = get_path();
            if (vec.empty()) {
                break;
            }
            flow += 1;
            // int64_t fuck = 0;
            for (int i = 0; i < vec.size() - 1; i++) {
                push(vec[i], vec[i + 1], 1);
            }
            DJ();
            copy_dist_to_phi();
        }
        return cost;
    }
};

int32_t main() {
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(nullptr);

    int n, k;
    std::cin >> n >> k;
    std::vector<std::pair<int, int>> input(n);
    for (auto& [l, r] : input) {
        std::cin >> l >> r;
    }
    Flow fl(2 * n + 3, 0, 2 * n + 2, n);
    fl.add_dir_edge(0, 1, k, 0);
    for (int i = 0; i < n; i++) {
        fl.add_dir_edge(1, 2 + i, 1, 0);
        fl.add_dir_edge(2 + i, 2 + n + i, 1, -inf);
        fl.add_dir_edge(2 + n + i, 2 * n + 2, 1, 0);
    }
    for (int i = 0; i < n; i++) {
        fl.beg[i] = input[i].first;
        fl.end[i] = input[i].second;
    }

    int64_t ans = fl.min_cost();
    ans += inf * 1LL * n;
    std::cout << ans << "\n";

    return 0;
}
