//#pragma GCC optimize("O3")

#include <iostream>
#include <algorithm>
#include <cassert>
#include <cmath>
#include <iomanip>
#include <vector>

using ld = long double;

ld const eps = 0.0000000001;

class Gauss{
  public:
    std::vector<std::vector<ld>> eq;
    std::vector<int> rep;
    int n;
    Gauss(int n_) {
      n = n_;
    }

    std::vector<ld> reduce() {
      int ptr = 0;

      while(ptr < eq.size()) {
        //std::cout << ptr << " " << eq.size() << '\n';
        int pos = -1;
        for(int i = 0; i < eq[ptr].size() - 1; i++)
          if(eps < std::fabs(eq[ptr][i])) { // <- add precision
            pos = i;
            break;
          }
        if(pos == -1) {
          std::swap(eq[ptr], eq.back());
          eq.pop_back();
          continue;
        }
        rep.push_back(pos);

        for(int i = 0; i < eq.size(); i++) {
          if(i != ptr && eps < std::fabs(eq[i][pos])) {
            ld coef = eq[i][pos] / eq[ptr][pos];
            if(eps < std::fabs(coef))
              for(int j = 0; j < eq[i].size(); j++)
                eq[i][j] -= eq[ptr][j] * coef;
          }
        }

        ptr++;
      }
      std::vector<ld> answer(n);
      //print();
      for(int i = 0; i < rep.size(); i++) {
        answer[rep[i]] = eq[i].back() / eq[i][rep[i]];
      }
      return answer;
    }
};

int const nmax = 35;
ld dp[1 + nmax][1 + nmax][2][2];

void testGauss() {
  int n, m;
  std::cin >> n >> m;
  Gauss gauss(n);
  for(int i = 1;i <= m; i++) {
    std::vector<ld> aux(n + 1);
    for(int j = 0; j < n + 1; j++)
      std::cin >> aux[j];
    gauss.eq.push_back(aux);
  }
  std::vector<ld> answer = gauss.reduce();
  for(int i = 0; i < answer.size(); i++)
    std::cout << answer[i] << " ";
  std::cout << '\n';
}

int main() {
  //testGauss();
  //return 0;

  ld p, p2;
  int n;
  int x, y;
  std::cin >> p >> n >> x >> y;
  p2 = 1 - p;

  int ptr = 0;
  for(int i = 0; i <= n; i++)
    for(int j = 0; j <= n; j++)
      for(int h = 0; h < 2; h++)
        for(int h2 = 0; h2 < 2; h2++)
          dp[i][j][h][h2] = ptr++;
  std::vector<std::vector<ld>> leg(ptr);
  for(int i = 0; i < leg.size(); i++)
    leg[i].resize(ptr + 1);

  for(int i = 0; i < ptr; i++)
    leg[i][i] = leg[i][ptr] = 1;

  for(int i = 0; i <= n; i++)
    for(int j = 0; j <= n; j++) { 
      leg[dp[i][j][0][1]][dp[std::max(0, i - 1)][j][0][1]] += -p;
      leg[dp[i][j][0][1]][dp[i][j][0][0]] += -p2;

      leg[dp[i][j][1][0]][dp[i][j][0][0]] += -p;
      leg[dp[i][j][1][0]][dp[i][std::max(0, j - 1)][1][0]] += -p2;


      if(i == j) {
        if(i < n) {
          leg[dp[i][j][0][0]][dp[i + 1][j][0][0]] += -p;
          leg[dp[i][j][0][0]][dp[i][j + 1][0][0]] += -p2;
        }
        continue;
      }
      if(i < j) {
        leg[dp[i][j][0][0]][dp[i + 1][j][0][0]] += -p;
        leg[dp[i][j][0][0]][dp[i][j][0][1]] += -p2; 
      } else if(j < i){
        leg[dp[i][j][0][0]][dp[i][j][1][0]] += -p;
        leg[dp[i][j][0][0]][dp[i][j + 1][0][0]] += -p2; 
      }
    }

  /*
  for(int i = 0; i < ptr; i++) {
    for(int j = 0; j <ptr + 1; j++)
      std::cout << leg[i][j] << " ";
    std::cout << '\n';
  }
  */
  Gauss gauss(ptr);
  for(int i = 0; i < ptr; i++)
    gauss.eq.push_back(leg[i]);
  std::vector<ld> answer = gauss.reduce();
  std::cout << std::setprecision(12) << std::fixed << answer[dp[x][y][0][0]] - 1 << std::endl;
  return 0;
}
